/***************************************************************************
 $RCSfile: editcategoryreport.h,v $
                             -------------------
    cvs         : $Id: editcategoryreport.h,v 1.2 2006/01/24 01:01:48 aquamaniac Exp $
    begin       : Mon Mar 01 2004
    copyright   : (C) 2004 by Martin Preuss
    email       : martin@libchipcard.de

 ***************************************************************************
 *          Please see toplevel file COPYING for license details           *
 ***************************************************************************/


#ifndef QBANKMANAGER_EDIT_CATEGORYREPORT_H
#define QBANKMANAGER_EDIT_CATEGORYREPORT_H



#include "editcategoryreport.ui.h"
#include <gwenhywfar/db.h>


class QComboBox;
class KBanking;


class EditCategoryReport:public EditCategoryReportUi {
  Q_OBJECT
private:
  GWEN_DB_NODE *_dbProfile;

  QComboBox *_getColumnComboBox(int idx);
  void _profileToGui(GWEN_DB_NODE *dbProfile);
  void _guiToProfile(GWEN_DB_NODE *dbProfile);

public:
  EditCategoryReport(KBanking *kb,
                     GWEN_DB_NODE *dbProfile,
                     QWidget* parent=0,
                     const char* name=0,
                     bool modal=FALSE,
                     Qt::WFlags fl =0);
  ~EditCategoryReport();

public slots:
  void accept();

};




#endif //QBANKMANAGER_EDIT_CATEGORYREPORT_H

